@@ -43,6 +43,15 @@ class Index:
         """Return value indicating whether the number of rows is zero."""
         return self._parent.empty
 
+    @property
+    def is_unique(self) -> bool:
+        """Check whether the index doesn't contain duplicates."""
+        columns = self._parent._columns
+        if not columns:
+            return True
+        order, merged = DataFrame._order([columns[c] for c in self._parent._index])
+        return len(np.unique(merged[order])) == len(merged)
+
     @property
     def is_monotonic_increasing(self) -> bool:
         """Check whether the index is sorted in ascending order."""
@@ -106,6 +115,30 @@ class Index:
         parent = self._parent
         return tuple(parent[c] for c in self._parent._index)
 
+    def duplicated(self, keep: Literal["first", "last"] = "first") -> npt.NDArray[np.int_]:
+        """
+        Return the positions of the duplicate index records.
+
+        :param keep: Select all subsequent occurrences of the same record as duplicates if \
+                     "first". "last" selects all preceding occurrences of the same record as \
+                     duplicates.
+        :return: Positions of the duplicates.
+        """
+        columns = self._parent._columns
+        if not columns:
+            return np.array([], dtype=int)
+        order, merged = DataFrame._order([columns[c] for c in self._parent._index])
+        if keep == "last":
+            order = order[::-1]
+        _, first_found = np.unique(merged[order], return_index=True)
+        if len(first_found) < len(merged):
+            if keep == "last":
+                first_found = np.arange(len(merged), dtype=int)[order][first_found]
+            mask = np.ones(len(merged), dtype=bool)
+            mask[first_found] = False
+            return np.flatnonzero(mask)
+        return np.array([], dtype=int)
+
 
 @dataclass(frozen=True, slots=True)
 class Grouper:
@@ -423,6 +456,33 @@ class DataFrame(metaclass=PureStaticDataFrameMethods):
 
         return df
 
+    def explode(self, column: Hashable, ignore_index: bool = False) -> "DataFrame":
+        """
+        Flatten a column with list-like elements, replicating other column values.
+
+        :param column: Column with list-likes inside that should be transformed.
+        :param ignore_index: Value indicating whether the index must be reset.
+        :return: DataFrame with >= rows than the origin.
+        """
+        values = self[column]
+        if values.dtype != object:
+            return self.reset_index() if ignore_index else self.copy()
+        checked_types = (tuple, list, np.ndarray)
+        repeat_counts = np.ones(len(values), dtype=int)
+        new_col = []
+        for i, v in enumerate(values):
+            if isinstance(v, checked_types):
+                repeat_counts[i] = len(v)
+                new_col.extend(v)
+            else:
+                new_col.append(v)
+        columns = {
+            k: np.repeat(v, repeat_counts) if k != column else np.asarray(new_col)
+            for k, v in self._columns.items()
+        }
+        df = DataFrame(columns, index=self._index if not ignore_index else None)
+        return df
+
     @property
     def index(self) -> Index:
         """Return the associated index."""
